| Title: | Setting Download Method to 'wget' |
|---|---|
| Description: | Provides function, wget_set(), to change the method (default to 'wget -c') using in download.file(). Using 'wget -c' allowing continued downloading, which is especially useful for slow internet connection and for downloading large files. User can run wget_unset() to restore previous setting. |
| Authors: | Guangchuang Yu [aut, cre] (ORCID: <https://orcid.org/0000-0002-6485-8781>) |
| Maintainer: | Guangchuang Yu <[email protected]> |
| License: | Artistic-2.0 |
| Version: | 0.0.4 |
| Built: | 2026-05-12 05:39:55 UTC |
| Source: | https://github.com/yulab-smu/wget |
set "download.file.method" to "wget" and "download.file.extra" to "-c"
wget_set(method = "wget", extra = "-c")wget_set(method = "wget", extra = "-c")
method |
download method (wget, default) |
extra |
extra parameter (-c, default) |
setting download method to "wget -c", so that it can continue the download from where it left off.
No return value, called for side effects
Guangchuang Yu
wget_set()wget_set()
unset download method setting by wget_set
wget_unset()wget_unset()
set the download method and extra parameter back to what it is or NULL if it is not specify
No return value, called for side effects
Guangchuang Yu
wget_unset()wget_unset()